@@ -100,8 +100,7 @@ from rql.nodes import (VariableRef, Comparison, Relation, Constant, Variable,
 
 from cubicweb import server
 from cubicweb.utils import make_uid
-from cubicweb.rqlrewrite import add_types_restriction
-from cubicweb.server.utils import cleanup_solutions
+from cubicweb.rqlrewrite import add_types_restriction, cleanup_solutions
 from cubicweb.server.ssplanner import SSPlanner, OneFetchStep
 from cubicweb.server.mssteps import *
 
